Class: Aws::AccessAnalyzer::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AccessAnalyzer::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-accessanalyzer/client.rb,
sig/client.rbs
Overview
An API client for AccessAnalyzer. To construct a client, you need to configure a :region and :credentials.
client = Aws::AccessAnalyzer::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelPolicyGenerationResponseSuccess, _CheckAccessNotGrantedResponseSuccess, _CheckNoNewAccessResponseSuccess, _CheckNoPublicAccessResponseSuccess, _CreateAccessPreviewResponseSuccess, _CreateAnalyzerResponseSuccess, _CreateServiceLinkedAnalyzerResponseSuccess, _GetAccessPreviewResponseSuccess, _GetAnalyzedResourceResponseSuccess, _GetAnalyzerResponseSuccess, _GetArchiveRuleResponseSuccess, _GetFindingRecommendationResponseSuccess, _GetFindingResponseSuccess, _GetFindingV2ResponseSuccess, _GetFindingsStatisticsResponseSuccess, _GetGeneratedPolicyResponseSuccess, _ListAccessPreviewFindingsResponseSuccess, _ListAccessPreviewsResponseSuccess, _ListAnalyzedResourcesResponseSuccess, _ListAnalyzersResponseSuccess, _ListArchiveRulesResponseSuccess, _ListFindingsResponseSuccess, _ListFindingsV2ResponseSuccess, _ListPolicyGenerationsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartPolicyGenerationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAnalyzerResponseSuccess, _ValidatePolicyResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#apply_archive_rule(params = {}) ⇒ Struct
Retroactively applies the archive rule to existing findings that meet the archive rule criteria.
-
#cancel_policy_generation(params = {}) ⇒ Struct
Cancels the requested policy generation.
-
#check_access_not_granted(params = {}) ⇒ Types::CheckAccessNotGrantedResponse
Checks whether the specified access isn't allowed by a policy.
-
#check_no_new_access(params = {}) ⇒ Types::CheckNoNewAccessResponse
Checks whether new access is allowed for an updated policy when compared to the existing policy.
-
#check_no_public_access(params = {}) ⇒ Types::CheckNoPublicAccessResponse
Checks whether a resource policy can grant public access to the specified resource type.
-
#create_access_preview(params = {}) ⇒ Types::CreateAccessPreviewResponse
Creates an access preview that allows you to preview IAM Access Analyzer findings for your resource before deploying resource permissions.
-
#create_analyzer(params = {}) ⇒ Types::CreateAnalyzerResponse
Creates an analyzer for your account.
-
#create_archive_rule(params = {}) ⇒ Struct
Creates an archive rule for the specified analyzer.
-
#create_service_linked_analyzer(params = {}) ⇒ Types::CreateServiceLinkedAnalyzerResponse
Creates a service-linked analyzer managed by an Amazon Web Services service.
-
#delete_analyzer(params = {}) ⇒ Struct
Deletes the specified analyzer.
-
#delete_archive_rule(params = {}) ⇒ Struct
Deletes the specified archive rule.
-
#delete_service_linked_analyzer(params = {}) ⇒ Struct
Deletes a service-linked analyzer.
-
#generate_finding_recommendation(params = {}) ⇒ Struct
Creates a recommendation for an unused permissions finding.
-
#get_access_preview(params = {}) ⇒ Types::GetAccessPreviewResponse
Retrieves information about an access preview for the specified analyzer.
-
#get_analyzed_resource(params = {}) ⇒ Types::GetAnalyzedResourceResponse
Retrieves information about a resource that was analyzed.
-
#get_analyzer(params = {}) ⇒ Types::GetAnalyzerResponse
Retrieves information about the specified analyzer.
-
#get_archive_rule(params = {}) ⇒ Types::GetArchiveRuleResponse
Retrieves information about an archive rule.
-
#get_finding(params = {}) ⇒ Types::GetFindingResponse
Retrieves information about the specified finding.
-
#get_finding_recommendation(params = {}) ⇒ Types::GetFindingRecommendationResponse
Retrieves information about a finding recommendation for the specified analyzer.
-
#get_finding_v2(params = {}) ⇒ Types::GetFindingV2Response
Retrieves information about the specified finding.
-
#get_findings_statistics(params = {}) ⇒ Types::GetFindingsStatisticsResponse
Retrieves a list of aggregated finding statistics for an external access or unused access analyzer.
-
#get_generated_policy(params = {}) ⇒ Types::GetGeneratedPolicyResponse
Retrieves the policy that was generated using
StartPolicyGeneration. -
#list_access_preview_findings(params = {}) ⇒ Types::ListAccessPreviewFindingsResponse
Retrieves a list of access preview findings generated by the specified access preview.
-
#list_access_previews(params = {}) ⇒ Types::ListAccessPreviewsResponse
Retrieves a list of access previews for the specified analyzer.
-
#list_analyzed_resources(params = {}) ⇒ Types::ListAnalyzedResourcesResponse
Retrieves a list of resources of the specified type that have been analyzed by the specified analyzer.
-
#list_analyzers(params = {}) ⇒ Types::ListAnalyzersResponse
Retrieves a list of analyzers.
-
#list_archive_rules(params = {}) ⇒ Types::ListArchiveRulesResponse
Retrieves a list of archive rules created for the specified analyzer.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a list of findings generated by the specified analyzer.
-
#list_findings_v2(params = {}) ⇒ Types::ListFindingsV2Response
Retrieves a list of findings generated by the specified analyzer.
-
#list_policy_generations(params = {}) ⇒ Types::ListPolicyGenerationsResponse
Lists all of the policy generations requested in the last seven days.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of tags applied to the specified resource.
-
#start_policy_generation(params = {}) ⇒ Types::StartPolicyGenerationResponse
Starts the policy generation request.
-
#start_resource_scan(params = {}) ⇒ Struct
Immediately starts a scan of the policies applied to the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from the specified resource.
-
#update_analyzer(params = {}) ⇒ Types::UpdateAnalyzerResponse
Modifies the configuration of an existing analyzer.
-
#update_archive_rule(params = {}) ⇒ Struct
Updates the criteria and values for the specified archive rule.
-
#update_findings(params = {}) ⇒ Struct
Updates the status for the specified findings.
-
#validate_policy(params = {}) ⇒ Types::ValidatePolicyResponse
Requests the validation of a policy and returns a list of findings.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3082 3083 3084 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3082 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3085 3086 3087 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3085 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#apply_archive_rule(params = {}) ⇒ Struct
Retroactively applies the archive rule to existing findings that meet the archive rule criteria.
82 |
# File 'sig/client.rbs', line 82 def apply_archive_rule: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3055 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AccessAnalyzer') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-accessanalyzer' context[:gem_version] = '1.96.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_policy_generation(params = {}) ⇒ Struct
Cancels the requested policy generation.
93 |
# File 'sig/client.rbs', line 93 def cancel_policy_generation: ( |
#check_access_not_granted(params = {}) ⇒ Types::CheckAccessNotGrantedResponse
Checks whether the specified access isn't allowed by a policy.
105 |
# File 'sig/client.rbs', line 105 def check_access_not_granted: ( |
#check_no_new_access(params = {}) ⇒ Types::CheckNoNewAccessResponse
Checks whether new access is allowed for an updated policy when compared to the existing policy.
You can find examples for reference policies and learn how to set up
and run a custom policy check for new access in the IAM Access
Analyzer custom policy checks samples repository on GitHub. The
reference policies in this repository are meant to be passed to the
existingPolicyDocument request parameter.
124 |
# File 'sig/client.rbs', line 124 def check_no_new_access: ( |
#check_no_public_access(params = {}) ⇒ Types::CheckNoPublicAccessResponse
Checks whether a resource policy can grant public access to the specified resource type.
138 |
# File 'sig/client.rbs', line 138 def check_no_public_access: ( |
#create_access_preview(params = {}) ⇒ Types::CreateAccessPreviewResponse
Creates an access preview that allows you to preview IAM Access Analyzer findings for your resource before deploying resource permissions.
149 |
# File 'sig/client.rbs', line 149 def create_access_preview: ( |
#create_analyzer(params = {}) ⇒ Types::CreateAnalyzerResponse
Creates an analyzer for your account.
262 |
# File 'sig/client.rbs', line 262 def create_analyzer: ( |
#create_archive_rule(params = {}) ⇒ Struct
Creates an archive rule for the specified analyzer. Archive rules automatically archive new findings that meet the criteria you define when you create the rule.
To learn about filter keys that you can use to create an archive rule, see IAM Access Analyzer filter keys in the IAM User Guide.
275 |
# File 'sig/client.rbs', line 275 def create_archive_rule: ( |
#create_service_linked_analyzer(params = {}) ⇒ Types::CreateServiceLinkedAnalyzerResponse
Creates a service-linked analyzer managed by an Amazon Web Services
service. This operation can only be invoked by authorized Amazon Web
Services services. Direct customer invocation returns
AccessDeniedException.
Service-linked analyzers enable Amazon Web Services services to create and manage analyzers on behalf of customers. The lifecycle of these analyzers is managed by the calling service.
293 |
# File 'sig/client.rbs', line 293 def create_service_linked_analyzer: ( |
#delete_analyzer(params = {}) ⇒ Struct
Deletes the specified analyzer. When you delete an analyzer, IAM Access Analyzer is disabled for the account or organization in the current or specific Region. All findings that were generated by the analyzer are deleted. You cannot undo this action.
304 |
# File 'sig/client.rbs', line 304 def delete_analyzer: ( |
#delete_archive_rule(params = {}) ⇒ Struct
Deletes the specified archive rule.
311 |
# File 'sig/client.rbs', line 311 def delete_archive_rule: ( |
#delete_service_linked_analyzer(params = {}) ⇒ Struct
Deletes a service-linked analyzer. This operation can be invoked by both authorized Amazon Web Services services and customers.
When invoked by a customer, IAM Access Analyzer performs a callback to
the managing service to verify whether the analyzer is still in use
and can be deleted. If the service indicates the analyzer is still in
use, the deletion is rejected with ConflictException.
319 |
# File 'sig/client.rbs', line 319 def delete_service_linked_analyzer: ( |
#generate_finding_recommendation(params = {}) ⇒ Struct
Creates a recommendation for an unused permissions finding.
326 |
# File 'sig/client.rbs', line 326 def generate_finding_recommendation: ( |
#get_access_preview(params = {}) ⇒ Types::GetAccessPreviewResponse
Retrieves information about an access preview for the specified analyzer.
337 |
# File 'sig/client.rbs', line 337 def get_access_preview: ( |
#get_analyzed_resource(params = {}) ⇒ Types::GetAnalyzedResourceResponse
Retrieves information about a resource that was analyzed.
348 |
# File 'sig/client.rbs', line 348 def get_analyzed_resource: ( |
#get_analyzer(params = {}) ⇒ Types::GetAnalyzerResponse
Retrieves information about the specified analyzer.
359 |
# File 'sig/client.rbs', line 359 def get_analyzer: ( |
#get_archive_rule(params = {}) ⇒ Types::GetArchiveRuleResponse
Retrieves information about an archive rule.
To learn about filter keys that you can use to create an archive rule, see IAM Access Analyzer filter keys in the IAM User Guide.
369 |
# File 'sig/client.rbs', line 369 def get_archive_rule: ( |
#get_finding(params = {}) ⇒ Types::GetFindingResponse
Retrieves information about the specified finding. GetFinding and
GetFindingV2 both use access-analyzer:GetFinding in the Action
element of an IAM policy statement. You must have permission to
perform the access-analyzer:GetFinding action.
380 |
# File 'sig/client.rbs', line 380 def get_finding: ( |
#get_finding_recommendation(params = {}) ⇒ Types::GetFindingRecommendationResponse
Retrieves information about a finding recommendation for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
397 |
# File 'sig/client.rbs', line 397 def get_finding_recommendation: ( |
#get_finding_v2(params = {}) ⇒ Types::GetFindingV2Response
Retrieves information about the specified finding. GetFinding and
GetFindingV2 both use access-analyzer:GetFinding in the Action
element of an IAM policy statement. You must have permission to
perform the access-analyzer:GetFinding action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
420 |
# File 'sig/client.rbs', line 420 def get_finding_v2: ( |
#get_findings_statistics(params = {}) ⇒ Types::GetFindingsStatisticsResponse
Retrieves a list of aggregated finding statistics for an external access or unused access analyzer.
434 |
# File 'sig/client.rbs', line 434 def get_findings_statistics: ( |
#get_generated_policy(params = {}) ⇒ Types::GetGeneratedPolicyResponse
Retrieves the policy that was generated using StartPolicyGeneration.
445 |
# File 'sig/client.rbs', line 445 def get_generated_policy: ( |
#list_access_preview_findings(params = {}) ⇒ Types::ListAccessPreviewFindingsResponse
Retrieves a list of access preview findings generated by the specified access preview.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
458 |
# File 'sig/client.rbs', line 458 def list_access_preview_findings: ( |
#list_access_previews(params = {}) ⇒ Types::ListAccessPreviewsResponse
Retrieves a list of access previews for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
478 |
# File 'sig/client.rbs', line 478 def list_access_previews: ( |
#list_analyzed_resources(params = {}) ⇒ Types::ListAnalyzedResourcesResponse
Retrieves a list of resources of the specified type that have been analyzed by the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
491 |
# File 'sig/client.rbs', line 491 def list_analyzed_resources: ( |
#list_analyzers(params = {}) ⇒ Types::ListAnalyzersResponse
Retrieves a list of analyzers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
505 |
# File 'sig/client.rbs', line 505 def list_analyzers: ( |
#list_archive_rules(params = {}) ⇒ Types::ListArchiveRulesResponse
Retrieves a list of archive rules created for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
518 |
# File 'sig/client.rbs', line 518 def list_archive_rules: ( |
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a list of findings generated by the specified analyzer.
ListFindings and ListFindingsV2 both use
access-analyzer:ListFindings in the Action element of an IAM
policy statement. You must have permission to perform the
access-analyzer:ListFindings action.
To learn about filter keys that you can use to retrieve a list of findings, see IAM Access Analyzer filter keys in the IAM User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
531 |
# File 'sig/client.rbs', line 531 def list_findings: ( |
#list_findings_v2(params = {}) ⇒ Types::ListFindingsV2Response
Retrieves a list of findings generated by the specified analyzer.
ListFindings and ListFindingsV2 both use
access-analyzer:ListFindings in the Action element of an IAM
policy statement. You must have permission to perform the
access-analyzer:ListFindings action.
To learn about filter keys that you can use to retrieve a list of findings, see IAM Access Analyzer filter keys in the IAM User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
554 |
# File 'sig/client.rbs', line 554 def list_findings_v2: ( |
#list_policy_generations(params = {}) ⇒ Types::ListPolicyGenerationsResponse
Lists all of the policy generations requested in the last seven days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
577 |
# File 'sig/client.rbs', line 577 def list_policy_generations: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of tags applied to the specified resource.
589 |
# File 'sig/client.rbs', line 589 def list_tags_for_resource: ( |
#start_policy_generation(params = {}) ⇒ Types::StartPolicyGenerationResponse
Starts the policy generation request.
599 |
# File 'sig/client.rbs', line 599 def start_policy_generation: ( |
#start_resource_scan(params = {}) ⇒ Struct
Immediately starts a scan of the policies applied to the specified resource.
620 |
# File 'sig/client.rbs', line 620 def start_resource_scan: ( |
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
631 |
# File 'sig/client.rbs', line 631 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from the specified resource.
641 |
# File 'sig/client.rbs', line 641 def untag_resource: ( |
#update_analyzer(params = {}) ⇒ Types::UpdateAnalyzerResponse
Modifies the configuration of an existing analyzer.
652 |
# File 'sig/client.rbs', line 652 def update_analyzer: ( |
#update_archive_rule(params = {}) ⇒ Struct
Updates the criteria and values for the specified archive rule.
659 |
# File 'sig/client.rbs', line 659 def update_archive_rule: ( |
#update_findings(params = {}) ⇒ Struct
Updates the status for the specified findings.
673 |
# File 'sig/client.rbs', line 673 def update_findings: ( |
#validate_policy(params = {}) ⇒ Types::ValidatePolicyResponse
Requests the validation of a policy and returns a list of findings. The findings help you identify issues and provide actionable recommendations to resolve the issue and enable you to author functional policies that meet security best practices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
688 |
# File 'sig/client.rbs', line 688 def validate_policy: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3075 3076 3077 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3075 def waiter_names [] end |