Class: Aws::AccessAnalyzer::Types::AccessPreview

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Contains information about an access preview.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analyzer_arnString

The ARN of the analyzer used to generate the access preview.

Returns:



91
92
93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 91

class AccessPreview < Struct.new(
  :id,
  :analyzer_arn,
  :configurations,
  :created_at,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#configurationsHash<String,Types::Configuration>

A map of resource ARNs for the proposed resource configuration.

Returns:



91
92
93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 91

class AccessPreview < Struct.new(
  :id,
  :analyzer_arn,
  :configurations,
  :created_at,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time at which the access preview was created.

Returns:



91
92
93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 91

class AccessPreview < Struct.new(
  :id,
  :analyzer_arn,
  :configurations,
  :created_at,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique ID for the access preview.

Returns:



91
92
93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 91

class AccessPreview < Struct.new(
  :id,
  :analyzer_arn,
  :configurations,
  :created_at,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the access preview.

  • Creating - The access preview creation is in progress.

  • Completed - The access preview is complete. You can preview findings for external access to the resource.

  • Failed - The access preview creation has failed.

Returns:



91
92
93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 91

class AccessPreview < Struct.new(
  :id,
  :analyzer_arn,
  :configurations,
  :created_at,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonTypes::AccessPreviewStatusReason

Provides more details about the current status of the access preview.

For example, if the creation of the access preview fails, a Failed status is returned. This failure can be due to an internal issue with the analysis or due to an invalid resource configuration.

Returns:



91
92
93
94
95
96
97
98
99
100
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 91

class AccessPreview < Struct.new(
  :id,
  :analyzer_arn,
  :configurations,
  :created_at,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end