Class: Aws::AccessAnalyzer::Types::AnalyzedResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Contains details about the analyzed resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionsArray<String>

The actions that an external principal is granted permission to use by the policy that generated the finding.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#analyzed_atTime

The time at which the resource was analyzed.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time at which the finding was created.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#errorString

An error message.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#is_publicBoolean

Indicates whether the policy that generated the finding grants public access to the resource.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The ARN of the resource that was analyzed.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#resource_owner_accountString

The Amazon Web Services account ID that owns the resource.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource that was analyzed.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#shared_viaArray<String>

Indicates how the access that generated the finding is granted. This is populated for Amazon S3 bucket findings.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the finding generated from the analyzed resource.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The time at which the finding was updated.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 424

class AnalyzedResource < Struct.new(
  :resource_arn,
  :resource_type,
  :created_at,
  :analyzed_at,
  :updated_at,
  :is_public,
  :actions,
  :shared_via,
  :status,
  :resource_owner_account,
  :error)
  SENSITIVE = []
  include Aws::Structure
end