Class: Aws::AccessAnalyzer::Types::Configuration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Note:

Configuration is a union - when making an API calls you must set exactly one of the members.

Note:

Configuration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Configuration corresponding to the set member.

Access control configuration structures for your resource. You specify the configuration as a type-value pair. You can specify only one type of access control configuration.

Defined Under Namespace

Classes: DynamodbStream, DynamodbTable, EbsSnapshot, EcrRepository, EfsFileSystem, IamRole, KmsKey, RdsDbClusterSnapshot, RdsDbSnapshot, S3Bucket, S3ExpressDirectoryBucket, SecretsManagerSecret, SnsTopic, SqsQueue, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dynamodb_streamTypes::DynamodbStreamConfiguration

The access control configuration is for a DynamoDB stream.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#dynamodb_tableTypes::DynamodbTableConfiguration

The access control configuration is for a DynamoDB table or index.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#ebs_snapshotTypes::EbsSnapshotConfiguration

The access control configuration is for an Amazon EBS volume snapshot.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#ecr_repositoryTypes::EcrRepositoryConfiguration

The access control configuration is for an Amazon ECR repository.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#efs_file_systemTypes::EfsFileSystemConfiguration

The access control configuration is for an Amazon EFS file system.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#iam_roleTypes::IamRoleConfiguration

The access control configuration is for an IAM role.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#kms_keyTypes::KmsKeyConfiguration

The access control configuration is for a KMS key.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#rds_db_cluster_snapshotTypes::RdsDbClusterSnapshotConfiguration

The access control configuration is for an Amazon RDS DB cluster snapshot.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#rds_db_snapshotTypes::RdsDbSnapshotConfiguration

The access control configuration is for an Amazon RDS DB snapshot.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#s3_bucketTypes::S3BucketConfiguration

The access control configuration is for an Amazon S3 bucket.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#s3_express_directory_bucketTypes::S3ExpressDirectoryBucketConfiguration

The access control configuration is for an Amazon S3 directory bucket.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#secrets_manager_secretTypes::SecretsManagerSecretConfiguration

The access control configuration is for a Secrets Manager secret.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#sns_topicTypes::SnsTopicConfiguration

The access control configuration is for an Amazon SNS topic



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#sqs_queueTypes::SqsQueueConfiguration

The access control configuration is for an Amazon SQS queue.



969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

class Configuration < Struct.new(
  :ebs_snapshot,
  :ecr_repository,
  :iam_role,
  :efs_file_system,
  :kms_key,
  :rds_db_cluster_snapshot,
  :rds_db_snapshot,
  :secrets_manager_secret,
  :s3_bucket,
  :sns_topic,
  :sqs_queue,
  :s3_express_directory_bucket,
  :dynamodb_stream,
  :dynamodb_table,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EbsSnapshot < Configuration; end
  class EcrRepository < Configuration; end
  class IamRole < Configuration; end
  class EfsFileSystem < Configuration; end
  class KmsKey < Configuration; end
  class RdsDbClusterSnapshot < Configuration; end
  class RdsDbSnapshot < Configuration; end
  class SecretsManagerSecret < Configuration; end
  class S3Bucket < Configuration; end
  class SnsTopic < Configuration; end
  class SqsQueue < Configuration; end
  class S3ExpressDirectoryBucket < Configuration; end
  class DynamodbStream < Configuration; end
  class DynamodbTable < Configuration; end
  class Unknown < Configuration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



969
970
971
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 969

def unknown
  @unknown
end