Class: Aws::AccessAnalyzer::Types::CreateAccessPreviewRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analyzer_arnString

The [ARN of the account analyzer] used to generate the access preview. You can only create an access preview for analyzers with an ‘Account` type and `Active` status.

[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-getting-started.html#permission-resources

Returns:

  • (String)


1056
1057
1058
1059
1060
1061
1062
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1056

class CreateAccessPreviewRequest < Struct.new(
  :analyzer_arn,
  :configurations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A client token.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1056
1057
1058
1059
1060
1061
1062
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1056

class CreateAccessPreviewRequest < Struct.new(
  :analyzer_arn,
  :configurations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#configurationsHash<String,Types::Configuration>

Access control configuration for your resource that is used to generate the access preview. The access preview includes findings for external access allowed to the resource with the proposed access control configuration. The configuration must contain exactly one element.

Returns:



1056
1057
1058
1059
1060
1061
1062
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1056

class CreateAccessPreviewRequest < Struct.new(
  :analyzer_arn,
  :configurations,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end