Class: Aws::AccessAnalyzer::Types::CreateAnalyzerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AccessAnalyzer::Types::CreateAnalyzerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-accessanalyzer/types.rb
Overview
Creates an analyzer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analyzer_name ⇒ String
The name of the analyzer to create.
-
#archive_rules ⇒ Array<Types::InlineArchiveRule>
Specifies the archive rules to add for the analyzer.
-
#client_token ⇒ String
A client token.
-
#configuration ⇒ Types::AnalyzerConfiguration
Specifies the configuration of the analyzer.
-
#tags ⇒ Hash<String,String>
An array of key-value pairs to apply to the analyzer.
-
#type ⇒ String
The type of analyzer to create.
Instance Attribute Details
#analyzer_name ⇒ String
The name of the analyzer to create.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1123 class CreateAnalyzerRequest < Struct.new( :analyzer_name, :type, :archive_rules, :tags, :client_token, :configuration) SENSITIVE = [] include Aws::Structure end |
#archive_rules ⇒ Array<Types::InlineArchiveRule>
Specifies the archive rules to add for the analyzer. Archive rules automatically archive findings that meet the criteria you define for the rule.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1123 class CreateAnalyzerRequest < Struct.new( :analyzer_name, :type, :archive_rules, :tags, :client_token, :configuration) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A client token.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1123 class CreateAnalyzerRequest < Struct.new( :analyzer_name, :type, :archive_rules, :tags, :client_token, :configuration) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::AnalyzerConfiguration
Specifies the configuration of the analyzer. If the analyzer is an unused access analyzer, the specified scope of unused access is used for the configuration. If the analyzer is an internal access analyzer, the specified internal access analysis rules are used for the configuration.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1123 class CreateAnalyzerRequest < Struct.new( :analyzer_name, :type, :archive_rules, :tags, :client_token, :configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
An array of key-value pairs to apply to the analyzer. You can use the set of Unicode letters, digits, whitespace, ‘_`, `.`, `/`, `=`, `+`, and `-`.
For the tag key, you can specify a value that is 1 to 128 characters in length and cannot be prefixed with ‘aws:`.
For the tag value, you can specify a value that is 0 to 256 characters in length.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1123 class CreateAnalyzerRequest < Struct.new( :analyzer_name, :type, :archive_rules, :tags, :client_token, :configuration) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of analyzer to create. You can create only one analyzer per account per Region. You can create up to 5 analyzers per organization per Region.
1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1123 class CreateAnalyzerRequest < Struct.new( :analyzer_name, :type, :archive_rules, :tags, :client_token, :configuration) SENSITIVE = [] include Aws::Structure end |