Class: Aws::AccessAnalyzer::Types::ExternalAccessDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Contains information about an external access finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionArray<String>

The action in the analyzed policy statement that an external principal has permission to use.

Returns:

  • (Array<String>)


1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1610

class ExternalAccessDetails < Struct.new(
  :action,
  :condition,
  :is_public,
  :principal,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#conditionHash<String,String>

The condition in the analyzed policy statement that resulted in an external access finding.

Returns:

  • (Hash<String,String>)


1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1610

class ExternalAccessDetails < Struct.new(
  :action,
  :condition,
  :is_public,
  :principal,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#is_publicBoolean

Specifies whether the external access finding is public.

Returns:

  • (Boolean)


1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1610

class ExternalAccessDetails < Struct.new(
  :action,
  :condition,
  :is_public,
  :principal,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#principalHash<String,String>

The external principal that has access to a resource within the zone of trust.

Returns:

  • (Hash<String,String>)


1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1610

class ExternalAccessDetails < Struct.new(
  :action,
  :condition,
  :is_public,
  :principal,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resource_control_policy_restrictionString

The type of restriction applied to the finding by the resource owner with an Organizations resource control policy (RCP).

  • ‘APPLICABLE`: There is an RCP present in the organization but IAM Access Analyzer does not include it in the evaluation of effective permissions. For example, if `s3:DeleteObject` is blocked by the RCP and the restriction is `APPLICABLE`, then `s3:DeleteObject` would still be included in the list of actions for the finding.

  • ‘FAILED_TO_EVALUATE_RCP`: There was an error evaluating the RCP.

  • ‘NOT_APPLICABLE`: There was no RCP present in the organization, or there was no RCP applicable to the resource. For example, the resource being analyzed is an Amazon RDS snapshot and there is an RCP in the organization, but the RCP only impacts Amazon S3 buckets.

  • ‘APPLIED`: This restriction is not currently available for external access findings.

Returns:

  • (String)


1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1610

class ExternalAccessDetails < Struct.new(
  :action,
  :condition,
  :is_public,
  :principal,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::FindingSource>

The sources of the external access finding. This indicates how the access that generated the finding is granted. It is populated for Amazon S3 bucket findings.

Returns:



1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1610

class ExternalAccessDetails < Struct.new(
  :action,
  :condition,
  :is_public,
  :principal,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end