Class: Aws::AccessAnalyzer::Types::Finding

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Contains information about a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionArray<String>

The action in the analyzed policy statement that an external principal has permission to use.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#analyzed_atTime

The time at which the resource was analyzed.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#conditionHash<String,String>

The condition in the analyzed policy statement that resulted in a finding.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time at which the finding was generated.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#errorString

An error.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the finding.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#is_publicBoolean

Indicates whether the policy that generated the finding allows public access to the resource.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#principalHash<String,String>

The external principal that has access to a resource within the zone of trust.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resourceString

The resource that an external principal has access to.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resource_control_policy_restrictionString

The type of restriction applied to the finding by the resource owner with an Organizations resource control policy (RCP).



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resource_owner_accountString

The Amazon Web Services account ID that owns the resource.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource identified in the finding.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::FindingSource>

The sources of the finding. This indicates how the access that generated the finding is granted. It is populated for Amazon S3 bucket findings.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the finding.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The time at which the finding was updated.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1726

class Finding < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end