Class: Aws::AccessAnalyzer::Types::FindingSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Contains information about a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionArray<String>

The action in the analyzed policy statement that an external principal has permission to use.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#analyzed_atTime

The time at which the resource-based policy that generated the finding was analyzed.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#conditionHash<String,String>

The condition in the analyzed policy statement that resulted in a finding.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time at which the finding was created.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#errorString

The error that resulted in an Error finding.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the finding.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#is_publicBoolean

Indicates whether the finding reports a resource that has a policy that allows public access.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#principalHash<String,String>

The external principal that has access to a resource within the zone of trust.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resourceString

The resource that the external principal has access to.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resource_control_policy_restrictionString

The type of restriction applied to the finding by the resource owner with an Organizations resource control policy (RCP).



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resource_owner_accountString

The Amazon Web Services account ID that owns the resource.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of the resource that the external principal has access to.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#sourcesArray<Types::FindingSource>

The sources of the finding. This indicates how the access that generated the finding is granted. It is populated for Amazon S3 bucket findings.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the finding.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The time at which the finding was most recently updated.



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1949

class FindingSummary < Struct.new(
  :id,
  :principal,
  :action,
  :resource,
  :is_public,
  :resource_type,
  :condition,
  :created_at,
  :analyzed_at,
  :updated_at,
  :status,
  :resource_owner_account,
  :error,
  :sources,
  :resource_control_policy_restriction)
  SENSITIVE = []
  include Aws::Structure
end