Class: Aws::AccessAnalyzer::Types::GetFindingsStatisticsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#findings_statisticsArray<Types::FindingsStatistics>

A group of external access or unused access findings statistics.

Returns:



2551
2552
2553
2554
2555
2556
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2551

class GetFindingsStatisticsResponse < Struct.new(
  :findings_statistics,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

The time at which the retrieval of the findings statistics was last updated. If the findings statistics have not been previously retrieved for the specified analyzer, this field will not be populated.

Returns:

  • (Time)


2551
2552
2553
2554
2555
2556
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2551

class GetFindingsStatisticsResponse < Struct.new(
  :findings_statistics,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end