Class: Aws::AccessAnalyzer::Types::InternalAccessAnalysisRule
- Inherits:
-
Struct
- Object
- Struct
- Aws::AccessAnalyzer::Types::InternalAccessAnalysisRule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-accessanalyzer/types.rb
Overview
Contains information about analysis rules for the internal access analyzer. Analysis rules determine which entities will generate findings based on the criteria you define when you create the rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inclusions ⇒ Array<Types::InternalAccessAnalysisRuleCriteria>
A list of rules for the internal access analyzer containing criteria to include in analysis.
Instance Attribute Details
#inclusions ⇒ Array<Types::InternalAccessAnalysisRuleCriteria>
A list of rules for the internal access analyzer containing criteria to include in analysis. Only resources that meet the rule criteria will generate findings.
2671 2672 2673 2674 2675 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2671 class InternalAccessAnalysisRule < Struct.new( :inclusions) SENSITIVE = [] include Aws::Structure end |