Class: Aws::AccessAnalyzer::Types::InternalAccessAnalysisRuleCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::AccessAnalyzer::Types::InternalAccessAnalysisRuleCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-accessanalyzer/types.rb
Overview
The criteria for an analysis rule for an internal access analyzer.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
A list of Amazon Web Services account IDs to apply to the internal access analysis rule criteria.
-
#resource_arns ⇒ Array<String>
A list of resource ARNs to apply to the internal access analysis rule criteria.
-
#resource_types ⇒ Array<String>
A list of resource types to apply to the internal access analysis rule criteria.
Instance Attribute Details
#account_ids ⇒ Array<String>
A list of Amazon Web Services account IDs to apply to the internal access analysis rule criteria. Account IDs can only be applied to the analysis rule criteria for organization-level analyzers.
2712 2713 2714 2715 2716 2717 2718 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2712 class InternalAccessAnalysisRuleCriteria < Struct.new( :account_ids, :resource_types, :resource_arns) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
A list of resource ARNs to apply to the internal access analysis rule criteria. The analyzer will only generate findings for resources that match these ARNs.
2712 2713 2714 2715 2716 2717 2718 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2712 class InternalAccessAnalysisRuleCriteria < Struct.new( :account_ids, :resource_types, :resource_arns) SENSITIVE = [] include Aws::Structure end |
#resource_types ⇒ Array<String>
A list of resource types to apply to the internal access analysis rule criteria. The analyzer will only generate findings for resources of these types. These resource types are currently supported for internal access analyzers:
-
‘AWS::S3::Bucket`
-
‘AWS::RDS::DBSnapshot`
-
‘AWS::RDS::DBClusterSnapshot`
-
‘AWS::S3Express::DirectoryBucket`
-
‘AWS::DynamoDB::Table`
-
‘AWS::DynamoDB::Stream`
2712 2713 2714 2715 2716 2717 2718 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2712 class InternalAccessAnalysisRuleCriteria < Struct.new( :account_ids, :resource_types, :resource_arns) SENSITIVE = [] include Aws::Structure end |