Class: Aws::AccessAnalyzer::Types::ListFindingsV2Request

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#analyzer_arnString

The ARN of the analyzer to retrieve findings from.

Returns:



3469
3470
3471
3472
3473
3474
3475
3476
3477
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 3469

class ListFindingsV2Request < Struct.new(
  :analyzer_arn,
  :filter,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#filterHash<String,Types::Criterion>

A filter to match for the findings to return.

Returns:



3469
3470
3471
3472
3473
3474
3475
3476
3477
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 3469

class ListFindingsV2Request < Struct.new(
  :analyzer_arn,
  :filter,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response.

Returns:



3469
3470
3471
3472
3473
3474
3475
3476
3477
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 3469

class ListFindingsV2Request < Struct.new(
  :analyzer_arn,
  :filter,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token used for pagination of results returned.

Returns:



3469
3470
3471
3472
3473
3474
3475
3476
3477
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 3469

class ListFindingsV2Request < Struct.new(
  :analyzer_arn,
  :filter,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end

#sortTypes::SortCriteria

The criteria used to sort.

Returns:



3469
3470
3471
3472
3473
3474
3475
3476
3477
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 3469

class ListFindingsV2Request < Struct.new(
  :analyzer_arn,
  :filter,
  :max_results,
  :next_token,
  :sort)
  SENSITIVE = []
  include Aws::Structure
end