Class: Aws::AccessAnalyzer::Types::NetworkOriginConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AccessAnalyzer::Types::NetworkOriginConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-accessanalyzer/types.rb
Overview
NetworkOriginConfiguration is a union - when making an API calls you must set exactly one of the members.
NetworkOriginConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of NetworkOriginConfiguration corresponding to the set member.
The proposed ‘InternetConfiguration` or `VpcConfiguration` to apply to the Amazon S3 access point. You can make the access point accessible from the internet, or you can specify that all requests made through that access point must originate from a specific virtual private cloud (VPC). You can specify only one type of network configuration. For more information, see [Creating access points].
[1]: docs.aws.amazon.com/AmazonS3/latest/dev/creating-access-points.html
Direct Known Subclasses
Defined Under Namespace
Classes: InternetConfiguration, Unknown, VpcConfiguration
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#internet_configuration ⇒ Types::InternetConfiguration
The configuration for the Amazon S3 access point or multi-region access point with an ‘Internet` origin.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
-
#vpc_configuration ⇒ Types::VpcConfiguration
The proposed virtual private cloud (VPC) configuration for the Amazon S3 access point.
Instance Attribute Details
#internet_configuration ⇒ Types::InternetConfiguration
The configuration for the Amazon S3 access point or multi-region access point with an ‘Internet` origin.
3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 3620 class NetworkOriginConfiguration < Struct.new( :vpc_configuration, :internet_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class VpcConfiguration < NetworkOriginConfiguration; end class InternetConfiguration < NetworkOriginConfiguration; end class Unknown < NetworkOriginConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3620 3621 3622 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 3620 def unknown @unknown end |
#vpc_configuration ⇒ Types::VpcConfiguration
The proposed virtual private cloud (VPC) configuration for the Amazon S3 access point. VPC configuration does not apply to multi-region access points. For more information, see [VpcConfiguration].
[1]: docs.aws.amazon.com/AmazonS3/latest/API/API_control_VpcConfiguration.html
3620 3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 3620 class NetworkOriginConfiguration < Struct.new( :vpc_configuration, :internet_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class VpcConfiguration < NetworkOriginConfiguration; end class InternetConfiguration < NetworkOriginConfiguration; end class Unknown < NetworkOriginConfiguration; end end |