Class: Aws::AccessAnalyzer::Types::Substring
- Inherits:
-
Struct
- Object
- Struct
- Aws::AccessAnalyzer::Types::Substring
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-accessanalyzer/types.rb
Overview
A reference to a substring of a literal string in a JSON document.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#length ⇒ Integer
The length of the substring.
-
#start ⇒ Integer
The start index of the substring, starting from 0.
Instance Attribute Details
#length ⇒ Integer
The length of the substring.
4546 4547 4548 4549 4550 4551 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 4546 class Substring < Struct.new( :start, :length) SENSITIVE = [] include Aws::Structure end |
#start ⇒ Integer
The start index of the substring, starting from 0.
4546 4547 4548 4549 4550 4551 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 4546 class Substring < Struct.new( :start, :length) SENSITIVE = [] include Aws::Structure end |