Class: Aws::AccessAnalyzer::Types::UnusedIamUserPasswordDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Contains information about an unused access finding for an IAM user password. IAM Access Analyzer charges for unused access analysis based on the number of IAM roles and users analyzed per month. For more details on pricing, see [IAM Access Analyzer pricing].

[1]: aws.amazon.com/iam/access-analyzer/pricing

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_accessedTime

The time at which the password was last accessed.

Returns:

  • (Time)


4866
4867
4868
4869
4870
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 4866

class UnusedIamUserPasswordDetails < Struct.new(
  :last_accessed)
  SENSITIVE = []
  include Aws::Structure
end