Class: Aws::AccessAnalyzer::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AccessAnalyzer::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-accessanalyzer/client.rb
Overview
An API client for AccessAnalyzer. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AccessAnalyzer::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#apply_archive_rule(params = {}) ⇒ Struct
Retroactively applies the archive rule to existing findings that meet the archive rule criteria.
-
#cancel_policy_generation(params = {}) ⇒ Struct
Cancels the requested policy generation.
-
#check_access_not_granted(params = {}) ⇒ Types::CheckAccessNotGrantedResponse
Checks whether the specified access isn’t allowed by a policy.
-
#check_no_new_access(params = {}) ⇒ Types::CheckNoNewAccessResponse
Checks whether new access is allowed for an updated policy when compared to the existing policy.
-
#check_no_public_access(params = {}) ⇒ Types::CheckNoPublicAccessResponse
Checks whether a resource policy can grant public access to the specified resource type.
-
#create_access_preview(params = {}) ⇒ Types::CreateAccessPreviewResponse
Creates an access preview that allows you to preview IAM Access Analyzer findings for your resource before deploying resource permissions.
-
#create_analyzer(params = {}) ⇒ Types::CreateAnalyzerResponse
Creates an analyzer for your account.
-
#create_archive_rule(params = {}) ⇒ Struct
Creates an archive rule for the specified analyzer.
-
#create_service_linked_analyzer(params = {}) ⇒ Types::CreateServiceLinkedAnalyzerResponse
Creates a service-linked analyzer managed by an Amazon Web Services service.
-
#delete_analyzer(params = {}) ⇒ Struct
Deletes the specified analyzer.
-
#delete_archive_rule(params = {}) ⇒ Struct
Deletes the specified archive rule.
-
#delete_service_linked_analyzer(params = {}) ⇒ Struct
Deletes a service-linked analyzer.
-
#generate_finding_recommendation(params = {}) ⇒ Struct
Creates a recommendation for an unused permissions finding.
-
#get_access_preview(params = {}) ⇒ Types::GetAccessPreviewResponse
Retrieves information about an access preview for the specified analyzer.
-
#get_analyzed_resource(params = {}) ⇒ Types::GetAnalyzedResourceResponse
Retrieves information about a resource that was analyzed.
-
#get_analyzer(params = {}) ⇒ Types::GetAnalyzerResponse
Retrieves information about the specified analyzer.
-
#get_archive_rule(params = {}) ⇒ Types::GetArchiveRuleResponse
Retrieves information about an archive rule.
-
#get_finding(params = {}) ⇒ Types::GetFindingResponse
Retrieves information about the specified finding.
-
#get_finding_recommendation(params = {}) ⇒ Types::GetFindingRecommendationResponse
Retrieves information about a finding recommendation for the specified analyzer.
-
#get_finding_v2(params = {}) ⇒ Types::GetFindingV2Response
Retrieves information about the specified finding.
-
#get_findings_statistics(params = {}) ⇒ Types::GetFindingsStatisticsResponse
Retrieves a list of aggregated finding statistics for an external access or unused access analyzer.
-
#get_generated_policy(params = {}) ⇒ Types::GetGeneratedPolicyResponse
Retrieves the policy that was generated using ‘StartPolicyGeneration`.
-
#list_access_preview_findings(params = {}) ⇒ Types::ListAccessPreviewFindingsResponse
Retrieves a list of access preview findings generated by the specified access preview.
-
#list_access_previews(params = {}) ⇒ Types::ListAccessPreviewsResponse
Retrieves a list of access previews for the specified analyzer.
-
#list_analyzed_resources(params = {}) ⇒ Types::ListAnalyzedResourcesResponse
Retrieves a list of resources of the specified type that have been analyzed by the specified analyzer.
-
#list_analyzers(params = {}) ⇒ Types::ListAnalyzersResponse
Retrieves a list of analyzers.
-
#list_archive_rules(params = {}) ⇒ Types::ListArchiveRulesResponse
Retrieves a list of archive rules created for the specified analyzer.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a list of findings generated by the specified analyzer.
-
#list_findings_v2(params = {}) ⇒ Types::ListFindingsV2Response
Retrieves a list of findings generated by the specified analyzer.
-
#list_policy_generations(params = {}) ⇒ Types::ListPolicyGenerationsResponse
Lists all of the policy generations requested in the last seven days.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of tags applied to the specified resource.
-
#start_policy_generation(params = {}) ⇒ Types::StartPolicyGenerationResponse
Starts the policy generation request.
-
#start_resource_scan(params = {}) ⇒ Struct
Immediately starts a scan of the policies applied to the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from the specified resource.
-
#update_analyzer(params = {}) ⇒ Types::UpdateAnalyzerResponse
Modifies the configuration of an existing analyzer.
-
#update_archive_rule(params = {}) ⇒ Struct
Updates the criteria and values for the specified archive rule.
-
#update_findings(params = {}) ⇒ Struct
Updates the status for the specified findings.
-
#validate_policy(params = {}) ⇒ Types::ValidatePolicyResponse
Requests the validation of a policy and returns a list of findings.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3082 3083 3084 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3082 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3085 3086 3087 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3085 def errors_module Errors end |
Instance Method Details
#apply_archive_rule(params = {}) ⇒ Struct
Retroactively applies the archive rule to existing findings that meet the archive rule criteria.
506 507 508 509 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 506 def apply_archive_rule(params = {}, = {}) req = build_request(:apply_archive_rule, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3055 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AccessAnalyzer') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-accessanalyzer' context[:gem_version] = '1.92.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_policy_generation(params = {}) ⇒ Struct
Cancels the requested policy generation.
531 532 533 534 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 531 def cancel_policy_generation(params = {}, = {}) req = build_request(:cancel_policy_generation, params) req.send_request() end |
#check_access_not_granted(params = {}) ⇒ Types::CheckAccessNotGrantedResponse
Checks whether the specified access isn’t allowed by a policy.
660 661 662 663 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 660 def check_access_not_granted(params = {}, = {}) req = build_request(:check_access_not_granted, params) req.send_request() end |
#check_no_new_access(params = {}) ⇒ Types::CheckNoNewAccessResponse
Checks whether new access is allowed for an updated policy when compared to the existing policy.
You can find examples for reference policies and learn how to set up and run a custom policy check for new access in the [IAM Access Analyzer custom policy checks samples] repository on GitHub. The reference policies in this repository are meant to be passed to the ‘existingPolicyDocument` request parameter.
[1]: github.com/aws-samples/iam-access-analyzer-custom-policy-check-samples
723 724 725 726 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 723 def check_no_new_access(params = {}, = {}) req = build_request(:check_no_new_access, params) req.send_request() end |
#check_no_public_access(params = {}) ⇒ Types::CheckNoPublicAccessResponse
Checks whether a resource policy can grant public access to the specified resource type.
802 803 804 805 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 802 def check_no_public_access(params = {}, = {}) req = build_request(:check_no_public_access, params) req.send_request() end |
#create_access_preview(params = {}) ⇒ Types::CreateAccessPreviewResponse
Creates an access preview that allows you to preview IAM Access Analyzer findings for your resource before deploying resource permissions.
970 971 972 973 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 970 def create_access_preview(params = {}, = {}) req = build_request(:create_access_preview, params) req.send_request() end |
#create_analyzer(params = {}) ⇒ Types::CreateAnalyzerResponse
Creates an analyzer for your account.
1078 1079 1080 1081 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1078 def create_analyzer(params = {}, = {}) req = build_request(:create_analyzer, params) req.send_request() end |
#create_archive_rule(params = {}) ⇒ Struct
Creates an archive rule for the specified analyzer. Archive rules automatically archive new findings that meet the criteria you define when you create the rule.
To learn about filter keys that you can use to create an archive rule, see [IAM Access Analyzer filter keys] in the **IAM User Guide**.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html
1131 1132 1133 1134 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1131 def create_archive_rule(params = {}, = {}) req = build_request(:create_archive_rule, params) req.send_request() end |
#create_service_linked_analyzer(params = {}) ⇒ Types::CreateServiceLinkedAnalyzerResponse
Creates a service-linked analyzer managed by an Amazon Web Services service. This operation can only be invoked by authorized Amazon Web Services services. Direct customer invocation returns ‘AccessDeniedException`.
Service-linked analyzers enable Amazon Web Services services to create and manage analyzers on behalf of customers. The lifecycle of these analyzers is managed by the calling service.
1224 1225 1226 1227 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1224 def create_service_linked_analyzer(params = {}, = {}) req = build_request(:create_service_linked_analyzer, params) req.send_request() end |
#delete_analyzer(params = {}) ⇒ Struct
Deletes the specified analyzer. When you delete an analyzer, IAM Access Analyzer is disabled for the account or organization in the current or specific Region. All findings that were generated by the analyzer are deleted. You cannot undo this action.
1256 1257 1258 1259 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1256 def delete_analyzer(params = {}, = {}) req = build_request(:delete_analyzer, params) req.send_request() end |
#delete_archive_rule(params = {}) ⇒ Struct
Deletes the specified archive rule.
1290 1291 1292 1293 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1290 def delete_archive_rule(params = {}, = {}) req = build_request(:delete_archive_rule, params) req.send_request() end |
#delete_service_linked_analyzer(params = {}) ⇒ Struct
Deletes a service-linked analyzer. This operation can be invoked by both authorized Amazon Web Services services and customers.
When invoked by a customer, IAM Access Analyzer performs a callback to the managing service to verify whether the analyzer is still in use and can be deleted. If the service indicates the analyzer is still in use, the deletion is rejected with ‘ConflictException`.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1327 def delete_service_linked_analyzer(params = {}, = {}) req = build_request(:delete_service_linked_analyzer, params) req.send_request() end |
#generate_finding_recommendation(params = {}) ⇒ Struct
Creates a recommendation for an unused permissions finding.
1377 1378 1379 1380 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1377 def generate_finding_recommendation(params = {}, = {}) req = build_request(:generate_finding_recommendation, params) req.send_request() end |
#get_access_preview(params = {}) ⇒ Types::GetAccessPreviewResponse
Retrieves information about an access preview for the specified analyzer.
1469 1470 1471 1472 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1469 def get_access_preview(params = {}, = {}) req = build_request(:get_access_preview, params) req.send_request() end |
#get_analyzed_resource(params = {}) ⇒ Types::GetAnalyzedResourceResponse
Retrieves information about a resource that was analyzed.
<note markdown=“1”> This action is supported only for external access analyzers.
</note>
1521 1522 1523 1524 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1521 def get_analyzed_resource(params = {}, = {}) req = build_request(:get_analyzed_resource, params) req.send_request() end |
#get_analyzer(params = {}) ⇒ Types::GetAnalyzerResponse
Retrieves information about the specified analyzer.
1573 1574 1575 1576 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1573 def get_analyzer(params = {}, = {}) req = build_request(:get_analyzer, params) req.send_request() end |
#get_archive_rule(params = {}) ⇒ Types::GetArchiveRuleResponse
Retrieves information about an archive rule.
To learn about filter keys that you can use to create an archive rule, see [IAM Access Analyzer filter keys] in the **IAM User Guide**.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html
1622 1623 1624 1625 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1622 def get_archive_rule(params = {}, = {}) req = build_request(:get_archive_rule, params) req.send_request() end |
#get_finding(params = {}) ⇒ Types::GetFindingResponse
Retrieves information about the specified finding. GetFinding and GetFindingV2 both use ‘access-analyzer:GetFinding` in the `Action` element of an IAM policy statement. You must have permission to perform the `access-analyzer:GetFinding` action.
<note markdown=“1”> GetFinding is supported only for external access analyzers. You must use GetFindingV2 for internal and unused access analyzers.
</note>
1686 1687 1688 1689 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1686 def get_finding(params = {}, = {}) req = build_request(:get_finding, params) req.send_request() end |
#get_finding_recommendation(params = {}) ⇒ Types::GetFindingRecommendationResponse
Retrieves information about a finding recommendation for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1831 1832 1833 1834 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1831 def get_finding_recommendation(params = {}, = {}) req = build_request(:get_finding_recommendation, params) req.send_request() end |
#get_finding_v2(params = {}) ⇒ Types::GetFindingV2Response
Retrieves information about the specified finding. GetFinding and GetFindingV2 both use ‘access-analyzer:GetFinding` in the `Action` element of an IAM policy statement. You must have permission to perform the `access-analyzer:GetFinding` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1938 1939 1940 1941 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1938 def get_finding_v2(params = {}, = {}) req = build_request(:get_finding_v2, params) req.send_request() end |
#get_findings_statistics(params = {}) ⇒ Types::GetFindingsStatisticsResponse
Retrieves a list of aggregated finding statistics for an external access or unused access analyzer.
1998 1999 2000 2001 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1998 def get_findings_statistics(params = {}, = {}) req = build_request(:get_findings_statistics, params) req.send_request() end |
#get_generated_policy(params = {}) ⇒ Types::GetGeneratedPolicyResponse
Retrieves the policy that was generated using ‘StartPolicyGeneration`.
2065 2066 2067 2068 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2065 def get_generated_policy(params = {}, = {}) req = build_request(:get_generated_policy, params) req.send_request() end |
#list_access_preview_findings(params = {}) ⇒ Types::ListAccessPreviewFindingsResponse
Retrieves a list of access preview findings generated by the specified access preview.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2147 2148 2149 2150 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2147 def list_access_preview_findings(params = {}, = {}) req = build_request(:list_access_preview_findings, params) req.send_request() end |
#list_access_previews(params = {}) ⇒ Types::ListAccessPreviewsResponse
Retrieves a list of access previews for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2196 2197 2198 2199 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2196 def list_access_previews(params = {}, = {}) req = build_request(:list_access_previews, params) req.send_request() end |
#list_analyzed_resources(params = {}) ⇒ Types::ListAnalyzedResourcesResponse
Retrieves a list of resources of the specified type that have been analyzed by the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2249 2250 2251 2252 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2249 def list_analyzed_resources(params = {}, = {}) req = build_request(:list_analyzed_resources, params) req.send_request() end |
#list_analyzers(params = {}) ⇒ Types::ListAnalyzersResponse
Retrieves a list of analyzers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2314 2315 2316 2317 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2314 def list_analyzers(params = {}, = {}) req = build_request(:list_analyzers, params) req.send_request() end |
#list_archive_rules(params = {}) ⇒ Types::ListArchiveRulesResponse
Retrieves a list of archive rules created for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2365 2366 2367 2368 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2365 def list_archive_rules(params = {}, = {}) req = build_request(:list_archive_rules, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a list of findings generated by the specified analyzer. ListFindings and ListFindingsV2 both use ‘access-analyzer:ListFindings` in the `Action` element of an IAM policy statement. You must have permission to perform the `access-analyzer:ListFindings` action.
To learn about filter keys that you can use to retrieve a list of findings, see [IAM Access Analyzer filter keys] in the **IAM User Guide**.
<note markdown=“1”> ListFindings is supported only for external access analyzers. You must use ListFindingsV2 for internal and unused access analyzers.
</note>
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2465 2466 2467 2468 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2465 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_findings_v2(params = {}) ⇒ Types::ListFindingsV2Response
Retrieves a list of findings generated by the specified analyzer. ListFindings and ListFindingsV2 both use ‘access-analyzer:ListFindings` in the `Action` element of an IAM policy statement. You must have permission to perform the `access-analyzer:ListFindings` action.
To learn about filter keys that you can use to retrieve a list of findings, see [IAM Access Analyzer filter keys] in the **IAM User Guide**.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2549 2550 2551 2552 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2549 def list_findings_v2(params = {}, = {}) req = build_request(:list_findings_v2, params) req.send_request() end |
#list_policy_generations(params = {}) ⇒ Types::ListPolicyGenerationsResponse
Lists all of the policy generations requested in the last seven days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2596 2597 2598 2599 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2596 def list_policy_generations(params = {}, = {}) req = build_request(:list_policy_generations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of tags applied to the specified resource.
2625 2626 2627 2628 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2625 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_policy_generation(params = {}) ⇒ Types::StartPolicyGenerationResponse
Starts the policy generation request.
2687 2688 2689 2690 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2687 def start_policy_generation(params = {}, = {}) req = build_request(:start_policy_generation, params) req.send_request() end |
#start_resource_scan(params = {}) ⇒ Struct
Immediately starts a scan of the policies applied to the specified resource.
<note markdown=“1”> This action is supported only for external access analyzers.
</note>
2729 2730 2731 2732 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2729 def start_resource_scan(params = {}, = {}) req = build_request(:start_resource_scan, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
2757 2758 2759 2760 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2757 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from the specified resource.
2783 2784 2785 2786 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2783 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_analyzer(params = {}) ⇒ Types::UpdateAnalyzerResponse
Modifies the configuration of an existing analyzer.
<note markdown=“1”> This action is not supported for external access analyzers.
</note>
2860 2861 2862 2863 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2860 def update_analyzer(params = {}, = {}) req = build_request(:update_analyzer, params) req.send_request() end |
#update_archive_rule(params = {}) ⇒ Struct
Updates the criteria and values for the specified archive rule.
2905 2906 2907 2908 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2905 def update_archive_rule(params = {}, = {}) req = build_request(:update_archive_rule, params) req.send_request() end |
#update_findings(params = {}) ⇒ Struct
Updates the status for the specified findings.
2952 2953 2954 2955 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2952 def update_findings(params = {}, = {}) req = build_request(:update_findings, params) req.send_request() end |
#validate_policy(params = {}) ⇒ Types::ValidatePolicyResponse
Requests the validation of a policy and returns a list of findings. The findings help you identify issues and provide actionable recommendations to resolve the issue and enable you to author functional policies that meet security best practices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3046 3047 3048 3049 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3046 def validate_policy(params = {}, = {}) req = build_request(:validate_policy, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3075 3076 3077 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3075 def waiter_names [] end |