Class: Aws::AccessAnalyzer::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AccessAnalyzer::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-accessanalyzer/client.rb
Overview
An API client for AccessAnalyzer. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AccessAnalyzer::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#apply_archive_rule(params = {}) ⇒ Struct
Retroactively applies the archive rule to existing findings that meet the archive rule criteria.
-
#cancel_policy_generation(params = {}) ⇒ Struct
Cancels the requested policy generation.
-
#check_access_not_granted(params = {}) ⇒ Types::CheckAccessNotGrantedResponse
Checks whether the specified access isn’t allowed by a policy.
-
#check_no_new_access(params = {}) ⇒ Types::CheckNoNewAccessResponse
Checks whether new access is allowed for an updated policy when compared to the existing policy.
-
#check_no_public_access(params = {}) ⇒ Types::CheckNoPublicAccessResponse
Checks whether a resource policy can grant public access to the specified resource type.
-
#create_access_preview(params = {}) ⇒ Types::CreateAccessPreviewResponse
Creates an access preview that allows you to preview IAM Access Analyzer findings for your resource before deploying resource permissions.
-
#create_analyzer(params = {}) ⇒ Types::CreateAnalyzerResponse
Creates an analyzer for your account.
-
#create_archive_rule(params = {}) ⇒ Struct
Creates an archive rule for the specified analyzer.
-
#create_service_linked_analyzer(params = {}) ⇒ Types::CreateServiceLinkedAnalyzerResponse
Creates a service-linked analyzer managed by an Amazon Web Services service.
-
#delete_analyzer(params = {}) ⇒ Struct
Deletes the specified analyzer.
-
#delete_archive_rule(params = {}) ⇒ Struct
Deletes the specified archive rule.
-
#delete_service_linked_analyzer(params = {}) ⇒ Struct
Deletes a service-linked analyzer.
-
#generate_finding_recommendation(params = {}) ⇒ Struct
Creates a recommendation for an unused permissions finding.
-
#get_access_preview(params = {}) ⇒ Types::GetAccessPreviewResponse
Retrieves information about an access preview for the specified analyzer.
-
#get_analyzed_resource(params = {}) ⇒ Types::GetAnalyzedResourceResponse
Retrieves information about a resource that was analyzed.
-
#get_analyzer(params = {}) ⇒ Types::GetAnalyzerResponse
Retrieves information about the specified analyzer.
-
#get_archive_rule(params = {}) ⇒ Types::GetArchiveRuleResponse
Retrieves information about an archive rule.
-
#get_finding(params = {}) ⇒ Types::GetFindingResponse
Retrieves information about the specified finding.
-
#get_finding_recommendation(params = {}) ⇒ Types::GetFindingRecommendationResponse
Retrieves information about a finding recommendation for the specified analyzer.
-
#get_finding_v2(params = {}) ⇒ Types::GetFindingV2Response
Retrieves information about the specified finding.
-
#get_findings_statistics(params = {}) ⇒ Types::GetFindingsStatisticsResponse
Retrieves a list of aggregated finding statistics for an external access or unused access analyzer.
-
#get_generated_policy(params = {}) ⇒ Types::GetGeneratedPolicyResponse
Retrieves the policy that was generated using ‘StartPolicyGeneration`.
-
#list_access_preview_findings(params = {}) ⇒ Types::ListAccessPreviewFindingsResponse
Retrieves a list of access preview findings generated by the specified access preview.
-
#list_access_previews(params = {}) ⇒ Types::ListAccessPreviewsResponse
Retrieves a list of access previews for the specified analyzer.
-
#list_analyzed_resources(params = {}) ⇒ Types::ListAnalyzedResourcesResponse
Retrieves a list of resources of the specified type that have been analyzed by the specified analyzer.
-
#list_analyzers(params = {}) ⇒ Types::ListAnalyzersResponse
Retrieves a list of analyzers.
-
#list_archive_rules(params = {}) ⇒ Types::ListArchiveRulesResponse
Retrieves a list of archive rules created for the specified analyzer.
-
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a list of findings generated by the specified analyzer.
-
#list_findings_v2(params = {}) ⇒ Types::ListFindingsV2Response
Retrieves a list of findings generated by the specified analyzer.
-
#list_policy_generations(params = {}) ⇒ Types::ListPolicyGenerationsResponse
Lists all of the policy generations requested in the last seven days.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of tags applied to the specified resource.
-
#start_policy_generation(params = {}) ⇒ Types::StartPolicyGenerationResponse
Starts the policy generation request.
-
#start_resource_scan(params = {}) ⇒ Struct
Immediately starts a scan of the policies applied to the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from the specified resource.
-
#update_analyzer(params = {}) ⇒ Types::UpdateAnalyzerResponse
Modifies the configuration of an existing analyzer.
-
#update_archive_rule(params = {}) ⇒ Struct
Updates the criteria and values for the specified archive rule.
-
#update_findings(params = {}) ⇒ Struct
Updates the status for the specified findings.
-
#validate_policy(params = {}) ⇒ Types::ValidatePolicyResponse
Requests the validation of a policy and returns a list of findings.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3084 3085 3086 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3084 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3087 3088 3089 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3087 def errors_module Errors end |
Instance Method Details
#apply_archive_rule(params = {}) ⇒ Struct
Retroactively applies the archive rule to existing findings that meet the archive rule criteria.
508 509 510 511 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 508 def apply_archive_rule(params = {}, = {}) req = build_request(:apply_archive_rule, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3057 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AccessAnalyzer') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-accessanalyzer' context[:gem_version] = '1.91.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_policy_generation(params = {}) ⇒ Struct
Cancels the requested policy generation.
533 534 535 536 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 533 def cancel_policy_generation(params = {}, = {}) req = build_request(:cancel_policy_generation, params) req.send_request() end |
#check_access_not_granted(params = {}) ⇒ Types::CheckAccessNotGrantedResponse
Checks whether the specified access isn’t allowed by a policy.
662 663 664 665 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 662 def check_access_not_granted(params = {}, = {}) req = build_request(:check_access_not_granted, params) req.send_request() end |
#check_no_new_access(params = {}) ⇒ Types::CheckNoNewAccessResponse
Checks whether new access is allowed for an updated policy when compared to the existing policy.
You can find examples for reference policies and learn how to set up and run a custom policy check for new access in the [IAM Access Analyzer custom policy checks samples] repository on GitHub. The reference policies in this repository are meant to be passed to the ‘existingPolicyDocument` request parameter.
[1]: github.com/aws-samples/iam-access-analyzer-custom-policy-check-samples
725 726 727 728 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 725 def check_no_new_access(params = {}, = {}) req = build_request(:check_no_new_access, params) req.send_request() end |
#check_no_public_access(params = {}) ⇒ Types::CheckNoPublicAccessResponse
Checks whether a resource policy can grant public access to the specified resource type.
804 805 806 807 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 804 def check_no_public_access(params = {}, = {}) req = build_request(:check_no_public_access, params) req.send_request() end |
#create_access_preview(params = {}) ⇒ Types::CreateAccessPreviewResponse
Creates an access preview that allows you to preview IAM Access Analyzer findings for your resource before deploying resource permissions.
972 973 974 975 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 972 def create_access_preview(params = {}, = {}) req = build_request(:create_access_preview, params) req.send_request() end |
#create_analyzer(params = {}) ⇒ Types::CreateAnalyzerResponse
Creates an analyzer for your account.
1080 1081 1082 1083 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1080 def create_analyzer(params = {}, = {}) req = build_request(:create_analyzer, params) req.send_request() end |
#create_archive_rule(params = {}) ⇒ Struct
Creates an archive rule for the specified analyzer. Archive rules automatically archive new findings that meet the criteria you define when you create the rule.
To learn about filter keys that you can use to create an archive rule, see [IAM Access Analyzer filter keys] in the **IAM User Guide**.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html
1133 1134 1135 1136 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1133 def create_archive_rule(params = {}, = {}) req = build_request(:create_archive_rule, params) req.send_request() end |
#create_service_linked_analyzer(params = {}) ⇒ Types::CreateServiceLinkedAnalyzerResponse
Creates a service-linked analyzer managed by an Amazon Web Services service. This operation can only be invoked by authorized Amazon Web Services services. Direct customer invocation returns ‘AccessDeniedException`.
Service-linked analyzers enable Amazon Web Services services to create and manage analyzers on behalf of customers. The lifecycle of these analyzers is managed by the calling service.
1226 1227 1228 1229 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1226 def create_service_linked_analyzer(params = {}, = {}) req = build_request(:create_service_linked_analyzer, params) req.send_request() end |
#delete_analyzer(params = {}) ⇒ Struct
Deletes the specified analyzer. When you delete an analyzer, IAM Access Analyzer is disabled for the account or organization in the current or specific Region. All findings that were generated by the analyzer are deleted. You cannot undo this action.
1258 1259 1260 1261 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1258 def delete_analyzer(params = {}, = {}) req = build_request(:delete_analyzer, params) req.send_request() end |
#delete_archive_rule(params = {}) ⇒ Struct
Deletes the specified archive rule.
1292 1293 1294 1295 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1292 def delete_archive_rule(params = {}, = {}) req = build_request(:delete_archive_rule, params) req.send_request() end |
#delete_service_linked_analyzer(params = {}) ⇒ Struct
Deletes a service-linked analyzer. This operation can be invoked by both authorized Amazon Web Services services and customers.
When invoked by a customer, IAM Access Analyzer performs a callback to the managing service to verify whether the analyzer is still in use and can be deleted. If the service indicates the analyzer is still in use, the deletion is rejected with ‘ConflictException`.
1329 1330 1331 1332 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1329 def delete_service_linked_analyzer(params = {}, = {}) req = build_request(:delete_service_linked_analyzer, params) req.send_request() end |
#generate_finding_recommendation(params = {}) ⇒ Struct
Creates a recommendation for an unused permissions finding.
1379 1380 1381 1382 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1379 def generate_finding_recommendation(params = {}, = {}) req = build_request(:generate_finding_recommendation, params) req.send_request() end |
#get_access_preview(params = {}) ⇒ Types::GetAccessPreviewResponse
Retrieves information about an access preview for the specified analyzer.
1471 1472 1473 1474 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1471 def get_access_preview(params = {}, = {}) req = build_request(:get_access_preview, params) req.send_request() end |
#get_analyzed_resource(params = {}) ⇒ Types::GetAnalyzedResourceResponse
Retrieves information about a resource that was analyzed.
<note markdown=“1”> This action is supported only for external access analyzers.
</note>
1523 1524 1525 1526 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1523 def get_analyzed_resource(params = {}, = {}) req = build_request(:get_analyzed_resource, params) req.send_request() end |
#get_analyzer(params = {}) ⇒ Types::GetAnalyzerResponse
Retrieves information about the specified analyzer.
1575 1576 1577 1578 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1575 def get_analyzer(params = {}, = {}) req = build_request(:get_analyzer, params) req.send_request() end |
#get_archive_rule(params = {}) ⇒ Types::GetArchiveRuleResponse
Retrieves information about an archive rule.
To learn about filter keys that you can use to create an archive rule, see [IAM Access Analyzer filter keys] in the **IAM User Guide**.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html
1624 1625 1626 1627 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1624 def get_archive_rule(params = {}, = {}) req = build_request(:get_archive_rule, params) req.send_request() end |
#get_finding(params = {}) ⇒ Types::GetFindingResponse
Retrieves information about the specified finding. GetFinding and GetFindingV2 both use ‘access-analyzer:GetFinding` in the `Action` element of an IAM policy statement. You must have permission to perform the `access-analyzer:GetFinding` action.
<note markdown=“1”> GetFinding is supported only for external access analyzers. You must use GetFindingV2 for internal and unused access analyzers.
</note>
1688 1689 1690 1691 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1688 def get_finding(params = {}, = {}) req = build_request(:get_finding, params) req.send_request() end |
#get_finding_recommendation(params = {}) ⇒ Types::GetFindingRecommendationResponse
Retrieves information about a finding recommendation for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1833 1834 1835 1836 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1833 def get_finding_recommendation(params = {}, = {}) req = build_request(:get_finding_recommendation, params) req.send_request() end |
#get_finding_v2(params = {}) ⇒ Types::GetFindingV2Response
Retrieves information about the specified finding. GetFinding and GetFindingV2 both use ‘access-analyzer:GetFinding` in the `Action` element of an IAM policy statement. You must have permission to perform the `access-analyzer:GetFinding` action.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1940 1941 1942 1943 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 1940 def get_finding_v2(params = {}, = {}) req = build_request(:get_finding_v2, params) req.send_request() end |
#get_findings_statistics(params = {}) ⇒ Types::GetFindingsStatisticsResponse
Retrieves a list of aggregated finding statistics for an external access or unused access analyzer.
2000 2001 2002 2003 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2000 def get_findings_statistics(params = {}, = {}) req = build_request(:get_findings_statistics, params) req.send_request() end |
#get_generated_policy(params = {}) ⇒ Types::GetGeneratedPolicyResponse
Retrieves the policy that was generated using ‘StartPolicyGeneration`.
2067 2068 2069 2070 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2067 def get_generated_policy(params = {}, = {}) req = build_request(:get_generated_policy, params) req.send_request() end |
#list_access_preview_findings(params = {}) ⇒ Types::ListAccessPreviewFindingsResponse
Retrieves a list of access preview findings generated by the specified access preview.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2149 2150 2151 2152 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2149 def list_access_preview_findings(params = {}, = {}) req = build_request(:list_access_preview_findings, params) req.send_request() end |
#list_access_previews(params = {}) ⇒ Types::ListAccessPreviewsResponse
Retrieves a list of access previews for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2198 2199 2200 2201 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2198 def list_access_previews(params = {}, = {}) req = build_request(:list_access_previews, params) req.send_request() end |
#list_analyzed_resources(params = {}) ⇒ Types::ListAnalyzedResourcesResponse
Retrieves a list of resources of the specified type that have been analyzed by the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2251 2252 2253 2254 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2251 def list_analyzed_resources(params = {}, = {}) req = build_request(:list_analyzed_resources, params) req.send_request() end |
#list_analyzers(params = {}) ⇒ Types::ListAnalyzersResponse
Retrieves a list of analyzers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2316 2317 2318 2319 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2316 def list_analyzers(params = {}, = {}) req = build_request(:list_analyzers, params) req.send_request() end |
#list_archive_rules(params = {}) ⇒ Types::ListArchiveRulesResponse
Retrieves a list of archive rules created for the specified analyzer.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2367 2368 2369 2370 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2367 def list_archive_rules(params = {}, = {}) req = build_request(:list_archive_rules, params) req.send_request() end |
#list_findings(params = {}) ⇒ Types::ListFindingsResponse
Retrieves a list of findings generated by the specified analyzer. ListFindings and ListFindingsV2 both use ‘access-analyzer:ListFindings` in the `Action` element of an IAM policy statement. You must have permission to perform the `access-analyzer:ListFindings` action.
To learn about filter keys that you can use to retrieve a list of findings, see [IAM Access Analyzer filter keys] in the **IAM User Guide**.
<note markdown=“1”> ListFindings is supported only for external access analyzers. You must use ListFindingsV2 for internal and unused access analyzers.
</note>
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2467 2468 2469 2470 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2467 def list_findings(params = {}, = {}) req = build_request(:list_findings, params) req.send_request() end |
#list_findings_v2(params = {}) ⇒ Types::ListFindingsV2Response
Retrieves a list of findings generated by the specified analyzer. ListFindings and ListFindingsV2 both use ‘access-analyzer:ListFindings` in the `Action` element of an IAM policy statement. You must have permission to perform the `access-analyzer:ListFindings` action.
To learn about filter keys that you can use to retrieve a list of findings, see [IAM Access Analyzer filter keys] in the **IAM User Guide**.
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/access-analyzer-reference-filter-keys.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2551 2552 2553 2554 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2551 def list_findings_v2(params = {}, = {}) req = build_request(:list_findings_v2, params) req.send_request() end |
#list_policy_generations(params = {}) ⇒ Types::ListPolicyGenerationsResponse
Lists all of the policy generations requested in the last seven days.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2598 2599 2600 2601 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2598 def list_policy_generations(params = {}, = {}) req = build_request(:list_policy_generations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves a list of tags applied to the specified resource.
2627 2628 2629 2630 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2627 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_policy_generation(params = {}) ⇒ Types::StartPolicyGenerationResponse
Starts the policy generation request.
2689 2690 2691 2692 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2689 def start_policy_generation(params = {}, = {}) req = build_request(:start_policy_generation, params) req.send_request() end |
#start_resource_scan(params = {}) ⇒ Struct
Immediately starts a scan of the policies applied to the specified resource.
<note markdown=“1”> This action is supported only for external access analyzers.
</note>
2731 2732 2733 2734 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2731 def start_resource_scan(params = {}, = {}) req = build_request(:start_resource_scan, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a tag to the specified resource.
2759 2760 2761 2762 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2759 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag from the specified resource.
2785 2786 2787 2788 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2785 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_analyzer(params = {}) ⇒ Types::UpdateAnalyzerResponse
Modifies the configuration of an existing analyzer.
<note markdown=“1”> This action is not supported for external access analyzers.
</note>
2862 2863 2864 2865 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2862 def update_analyzer(params = {}, = {}) req = build_request(:update_analyzer, params) req.send_request() end |
#update_archive_rule(params = {}) ⇒ Struct
Updates the criteria and values for the specified archive rule.
2907 2908 2909 2910 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2907 def update_archive_rule(params = {}, = {}) req = build_request(:update_archive_rule, params) req.send_request() end |
#update_findings(params = {}) ⇒ Struct
Updates the status for the specified findings.
2954 2955 2956 2957 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 2954 def update_findings(params = {}, = {}) req = build_request(:update_findings, params) req.send_request() end |
#validate_policy(params = {}) ⇒ Types::ValidatePolicyResponse
Requests the validation of a policy and returns a list of findings. The findings help you identify issues and provide actionable recommendations to resolve the issue and enable you to author functional policies that meet security best practices.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3048 3049 3050 3051 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3048 def validate_policy(params = {}, = {}) req = build_request(:validate_policy, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3077 3078 3079 |
# File 'lib/aws-sdk-accessanalyzer/client.rb', line 3077 def waiter_names [] end |