Class: Aws::AccessAnalyzer::Types::CreateServiceLinkedAnalyzerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-accessanalyzer/types.rb

Overview

Creates a service-linked analyzer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#archive_rulesArray<Types::InlineArchiveRule>

Specifies the archive rules to add for the analyzer. Archive rules automatically archive findings that meet the criteria you define for the rule.

Returns:



1207
1208
1209
1210
1211
1212
1213
1214
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1207

class CreateServiceLinkedAnalyzerRequest < Struct.new(
  :type,
  :archive_rules,
  :client_token,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A client token.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1207
1208
1209
1210
1211
1212
1213
1214
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1207

class CreateServiceLinkedAnalyzerRequest < Struct.new(
  :type,
  :archive_rules,
  :client_token,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::AnalyzerConfiguration

Specifies the configuration of the analyzer. The specified scope of unused access is used for the configuration.



1207
1208
1209
1210
1211
1212
1213
1214
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1207

class CreateServiceLinkedAnalyzerRequest < Struct.new(
  :type,
  :archive_rules,
  :client_token,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of analyzer to create. Valid values are ‘ACCOUNT_UNUSED_ACCESS` and `ORGANIZATION_UNUSED_ACCESS`.

Returns:

  • (String)


1207
1208
1209
1210
1211
1212
1213
1214
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 1207

class CreateServiceLinkedAnalyzerRequest < Struct.new(
  :type,
  :archive_rules,
  :client_token,
  :configuration)
  SENSITIVE = []
  include Aws::Structure
end