Class: Aws::AccessAnalyzer::Types::GetFindingsStatisticsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::AccessAnalyzer::Types::GetFindingsStatisticsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-accessanalyzer/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#findings_statistics ⇒ Array<Types::FindingsStatistics>
A group of external access or unused access findings statistics.
-
#last_updated_at ⇒ Time
The time at which the retrieval of the findings statistics was last updated.
Instance Attribute Details
#findings_statistics ⇒ Array<Types::FindingsStatistics>
A group of external access or unused access findings statistics.
2551 2552 2553 2554 2555 2556 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2551 class GetFindingsStatisticsResponse < Struct.new( :findings_statistics, :last_updated_at) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
The time at which the retrieval of the findings statistics was last updated. If the findings statistics have not been previously retrieved for the specified analyzer, this field will not be populated.
2551 2552 2553 2554 2555 2556 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2551 class GetFindingsStatisticsResponse < Struct.new( :findings_statistics, :last_updated_at) SENSITIVE = [] include Aws::Structure end |