Class: Aws::AccessAnalyzer::Types::InternalAccessConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::AccessAnalyzer::Types::InternalAccessConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-accessanalyzer/types.rb
Overview
Specifies the configuration of an internal access analyzer for an Amazon Web Services organization or account. This configuration determines how the analyzer evaluates internal access within your Amazon Web Services environment.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#analysis_rule ⇒ Types::InternalAccessAnalysisRule
Contains information about analysis rules for the internal access analyzer.
Instance Attribute Details
#analysis_rule ⇒ Types::InternalAccessAnalysisRule
Contains information about analysis rules for the internal access analyzer. These rules determine which resources and access patterns will be analyzed.
2733 2734 2735 2736 2737 |
# File 'lib/aws-sdk-accessanalyzer/types.rb', line 2733 class InternalAccessConfiguration < Struct.new( :analysis_rule) SENSITIVE = [] include Aws::Structure end |